@@ -9,7 +9,7 @@ module Rufus; end
 
 class Rufus::Scheduler
 
-  VERSION = '3.8.0'
+  VERSION = '3.8.2'
 
   EoTime = ::EtOrbi::EoTime
 
@@ -443,10 +443,14 @@ class Rufus::Scheduler
     ms = {}; mutexes.each { |k, v| ms[k] = v.locked? }
 
     stderr.puts("{ #{pre} rufus-scheduler intercepted an error:")
-    stderr.puts("  #{pre}   job:")
-    stderr.puts("  #{pre}     #{job.class} #{job.original.inspect} #{job.opts.inspect}")
-    stderr.puts("  #{pre}     #{job.source_location.inspect}")
-    # TODO: eventually use a Job#detail or something like that
+    if job
+      stderr.puts("  #{pre}   job:")
+      stderr.puts("  #{pre}     #{job.class} #{job.original.inspect} #{job.opts.inspect}")
+      stderr.puts("  #{pre}     #{job.source_location.inspect}")
+      # TODO: eventually use a Job#detail or something like that
+    else
+      stderr.puts("  #{pre}   job: (error did not occur in a job)")
+    end
     stderr.puts("  #{pre}   error:")
     stderr.puts("  #{pre}     #{err.object_id}")
     stderr.puts("  #{pre}     #{err.class}")
@@ -530,7 +534,7 @@ class Rufus::Scheduler
 
     unlock
 
-    @thread.join
+    @thread.join unless @thread == Thread.current
   end
   alias stop shutdown
 
@@ -583,7 +587,7 @@ class Rufus::Scheduler
       r =
         begin
           @join_queue.pop(true)
-        rescue ThreadError => e
+        rescue ThreadError
           # #<ThreadError: queue empty>
           false
         end
@@ -630,12 +634,20 @@ class Rufus::Scheduler
       Thread.new do
 
         while @started_at do
+          begin
 
-          unschedule_jobs
-          trigger_jobs unless @paused_at
-          timeout_jobs
+            unschedule_jobs
+            trigger_jobs unless @paused_at
+            timeout_jobs
 
-          sleep(@frequency)
+            sleep(@frequency)
+
+          rescue => err
+            #
+            # for `blocking: true` jobs mostly
+            #
+            on_error(nil, err)
+          end
         end
 
         rejoin
