@@ -1,13 +1,13 @@
 
-module Rufus
+class Rufus::Scheduler
 
-  class Scheduler
+  class << self
 
     #--
     # time and string methods
     #++
 
-    def self.parse(o, opts={})
+    def parse(o, opts={})
 
       opts[:no_error] = true
 
@@ -17,17 +17,14 @@ module Rufus
       fail(ArgumentError.new("couldn't parse #{o.inspect} (#{o.class})"))
     end
 
-    def self.parse_cron(o, opts)
+    def parse_cron(o, opts={})
 
-      o.is_a?(CronLine) ? o : CronLine.new(o)
-
-    rescue ArgumentError => ae
-
-      return nil if opts[:no_error]
-      fail ae
+      opts[:no_error] ?
+        Fugit.parse_cron(o) :
+        Fugit.do_parse_cron(o)
     end
 
-    def self.parse_in(o, opts={})
+    def parse_in(o, opts={})
 
       #o.is_a?(String) ? parse_duration(o, opts) : o
 
@@ -42,7 +39,7 @@ module Rufus
       fail ae
     end
 
-    def self.parse_at(o, opts={})
+    def parse_at(o, opts={})
 
       return o if o.is_a?(EoTime)
       return EoTime.make(o) if o.is_a?(Time)
@@ -54,23 +51,6 @@ module Rufus
       fail se
     end
 
-    DURATIONS2M = [
-      [ 'y', 365 * 24 * 3600 ],
-      [ 'M', 30 * 24 * 3600 ],
-      [ 'w', 7 * 24 * 3600 ],
-      [ 'd', 24 * 3600 ],
-      [ 'h', 3600 ],
-      [ 'm', 60 ],
-      [ 's', 1 ]
-    ]
-    DURATIONS2 = DURATIONS2M.dup
-    DURATIONS2.delete_at(1)
-
-    DURATIONS = DURATIONS2M.inject({}) { |r, (k, v)| r[k] = v; r }
-    DURATION_LETTERS = DURATIONS.keys.join
-
-    DU_KEYS = DURATIONS2M.collect { |k, v| k.to_sym }
-
     # Turns a string like '1m10s' into a float like '70.0', more formally,
     # turns a time duration expressed as a string into a Float instance
     # (millisecond count).
@@ -98,37 +78,17 @@ module Rufus
     #   Rufus::Scheduler.parse_duration "-0.5"   # => -0.5
     #   Rufus::Scheduler.parse_duration "-1h"    # => -3600.0
     #
-    def self.parse_duration(string, opts={})
+    def parse_duration(str, opts={})
 
-      s = string.to_s.strip
-      mod = s[0, 1] == '-' ? -1 : 1
-      s = s[1..-1] if mod == -1
-
-      ss = mod < 0 ? '-' : ''
-      r = 0.0
-
-      s.scan(/(\d*\.\d+|\d+\.?)([#{DURATION_LETTERS}]?)/) do |f, d|
-        ss += "#{f}#{d}"
-        r += f.to_f * (DURATIONS[d] || 1.0)
-      end
-
-      if ss == '-' || ss != string.to_s.strip
-        return nil if opts[:no_error]
-        fail ArgumentError.new("invalid time duration #{string.inspect}")
-      end
-
-      mod * r
+      d =
+        opts[:no_error] ?
+        Fugit::Duration.parse(str, opts) :
+        Fugit::Duration.do_parse(str, opts)
+      d ?
+        d.to_sec :
+        nil
     end
 
-    class << self
-      #-
-      # for compatibility with rufus-scheduler 2.x
-      #+
-      alias parse_duration_string parse_duration
-      alias parse_time_string parse_duration
-    end
-
-
     # Turns a number of seconds into a a time string
     #
     #   Rufus.to_duration 0                    # => '0s'
@@ -158,45 +118,27 @@ module Rufus
     #
     # * :months, if set to true, months (M) of 30 days will be taken into
     #   account when building up the result
-    # * :drop_seconds, if set to true, seconds and milliseconds will be trimmed
-    #   from the result
+    # * :drop_seconds, if set to true, seconds and milliseconds will be
+    #   trimmed from the result
     #
-    def self.to_duration(seconds, options={})
+    def to_duration(seconds, options={})
 
-      h = to_duration_hash(seconds, options)
+      #d = Fugit::Duration.parse(seconds, options).deflate
+      #d = d.drop_seconds if options[:drop_seconds]
+      #d = d.deflate(:month => options[:months]) if options[:months]
+      #d.to_rufus_s
 
-      return (options[:drop_seconds] ? '0m' : '0s') if h.empty?
-
-      s =
-        DU_KEYS.inject('') { |r, key|
-          count = h[key]
-          count = nil if count == 0
-          r << "#{count}#{key}" if count
-          r
-        }
-
-      ms = h[:ms]
-      s << ms.to_s if ms
-
-      s
-    end
-
-    class << self
-      #-
-      # for compatibility with rufus-scheduler 2.x
-      #+
-      alias to_duration_string to_duration
-      alias to_time_string to_duration
+      to_fugit_duration(seconds, options).to_rufus_s
     end
 
     # Turns a number of seconds (integer or Float) into a hash like in :
     #
     #   Rufus.to_duration_hash 0.051
-    #     # => { :ms => "51" }
+    #     # => { :s => 0.051 }
     #   Rufus.to_duration_hash 7.051
-    #     # => { :s => 7, :ms => "51" }
+    #     # => { :s => 7.051 }
     #   Rufus.to_duration_hash 0.120 + 30 * 24 * 3600 + 1
-    #     # => { :w => 4, :d => 2, :s => 1, :ms => "120" }
+    #     # => { :w => 4, :d => 2, :s => 1.120 }
     #
     # This method is used by to_duration behind the scenes.
     #
@@ -204,62 +146,71 @@ module Rufus
     #
     # * :months, if set to true, months (M) of 30 days will be taken into
     #   account when building up the result
-    # * :drop_seconds, if set to true, seconds and milliseconds will be trimmed
-    #   from the result
+    # * :drop_seconds, if set to true, seconds and milliseconds will be
+    #   trimmed from the result
     #
-    def self.to_duration_hash(seconds, options={})
+    def to_duration_hash(seconds, options={})
 
-      h = {}
+      to_fugit_duration(seconds, options).to_rufus_h
+    end
 
-      if seconds.is_a?(Float)
-        h[:ms] = (seconds % 1 * 1000).to_i
-        seconds = seconds.to_i
-      end
+    # Used by both .to_duration and .to_duration_hash
+    #
+    def to_fugit_duration(seconds, options={})
 
-      if options[:drop_seconds]
-        h.delete(:ms)
-        seconds = (seconds - seconds % 60)
-      end
+      d = Fugit::Duration
+        .parse(seconds, options)
+        .deflate
 
-      durations = options[:months] ? DURATIONS2M : DURATIONS2
+      d = d.drop_seconds if options[:drop_seconds]
+      d = d.deflate(:month => options[:months]) if options[:months]
 
-      durations.each do |key, duration|
-
-        count = seconds / duration
-        seconds = seconds % duration
-
-        h[key.to_sym] = count if count > 0
-      end
-
-      h
+      d
     end
 
     #--
     # misc
     #++
 
-    # Produces the UTC string representation of a Time instance
-    #
-    # like "2009/11/23 11:11:50.947109 UTC"
-    #
-    def self.utc_to_s(t=Time.now)
+    if RUBY_VERSION > '1.9.9'
 
-      "#{t.utc.strftime('%Y-%m-%d %H:%M:%S')}.#{sprintf('%06d', t.usec)} UTC"
+      # Produces the UTC string representation of a Time instance
+      #
+      # like "2009/11/23 11:11:50.947109 UTC"
+      #
+      def utc_to_s(t=Time.now)
+        "#{t.dup.utc.strftime('%F %T.%6N')} UTC"
+      end
+
+      # Produces a hour/min/sec/milli string representation of Time instance
+      #
+      def h_to_s(t=Time.now)
+        t.strftime('%T.%6N')
+      end
+    else
+
+      def utc_to_s(t=Time.now)
+        "#{t.utc.strftime('%Y-%m-%d %H:%M:%S')}.#{sprintf('%06d', t.usec)} UTC"
+      end
+      def h_to_s(t=Time.now)
+        "#{t.strftime('%H:%M:%S')}.#{sprintf('%06d', t.usec)}"
+      end
     end
 
-    # Produces a hour/min/sec/milli string representation of Time instance
-    #
-    def self.h_to_s(t=Time.now)
-
-      "#{t.strftime('%H:%M:%S')}.#{sprintf('%06d', t.usec)}"
+    if defined?(Process::CLOCK_MONOTONIC)
+      def monow; Process.clock_gettime(Process::CLOCK_MONOTONIC); end
+    else
+      def monow; Time.now.to_f; end
     end
 
-    # Debugging tools...
-    #
-    class D
+    def ltstamp; Time.now.strftime('%FT%T.%3N'); end
+  end
 
-      def self.h_to_s(t=Time.now); Rufus::Scheduler.h_to_s(t); end
-    end
+  # Debugging tools...
+  #
+  class D
+
+    def self.h_to_s(t=Time.now); Rufus::Scheduler.h_to_s(t); end
   end
 end
 
