@@ -75,5 +75,24 @@ describe Rufus::Scheduler::AtJob do
       expect(t1).to be > t
     end
   end
+
+  describe '#next_times' do
+
+    it 'returns the next n times' do
+
+      job = @scheduler.schedule_at Time.now + 1 do; end
+
+      expect(job.next_times(3)).to eq([ job.next_time ])
+    end
+
+    it 'returns an empty array if it already triggered' do
+
+      job = @scheduler.schedule_at Time.now + 0.001 do; end
+
+      sleep 0.350
+
+      expect(job.next_times(3)).to eq([])
+    end
+  end
 end
 
