@@ -286,7 +286,7 @@ describe Rufus::Scheduler do
       @scheduler.unschedule(job)
 
       sleep 1.5
-      expect(counter).to eq(c)
+      expect(counter).to be_between(c, c + 1)
     end
   end
 
@@ -653,6 +653,8 @@ describe Rufus::Scheduler do
 
     it 'respects :times for repeat jobs' do
 
+      loop { s = Time.now.sec; break if s > 10 && s < 50 }
+
       j0 = @scheduler.schedule_every '1m', :times => 10 do; end
 
       t0 = Time.parse((Time.now + 5 * 60).strftime('%Y-%m-%d %H:%M:01'))
@@ -1336,11 +1338,11 @@ describe Rufus::Scheduler do
 
       wait_until { $out.size > 2 }
 
-      expect($out.take(3)).to eq([
-        "pre #{job_id1}",
-        "pre #{job_id2}",
-        job_id2
-      ])
+      expect(
+        $out.take(2).sort + $out[2, 1]
+      ).to eq(
+        [ "pre #{job_id1}", "pre #{job_id2}" ].sort + [ job_id2 ]
+      )
     end
   end
 
